eapol/eapol_framework/eapol_symbian/am/type/aka/symbian/plugin/inc/EapAkaDbUtils.h
branchRCL_3
changeset 46 c74b3d9f6b9e
parent 45 bad0cc58d154
--- a/eapol/eapol_framework/eapol_symbian/am/type/aka/symbian/plugin/inc/EapAkaDbUtils.h	Tue Aug 31 15:16:37 2010 +0300
+++ b/eapol/eapol_framework/eapol_symbian/am/type/aka/symbian/plugin/inc/EapAkaDbUtils.h	Wed Sep 01 12:23:57 2010 +0100
@@ -16,7 +16,7 @@
 */
 
 /*
-* %version: 7.1.6 %
+* %version: 9 %
 */
 
 #ifndef _EAPAKADBUTILS_H_
@@ -29,22 +29,32 @@
 
 // LOCAL CONSTANTS
 
-// For EAP-AKA private database. Database will be in the private folder of EAP-server (20026FCB).
-// The maximum length of database name is 0x40 (KDbMaxName), which is defined in d32dbms.h.
+#ifdef SYMBIAN_SECURE_DBMS
+// For EAP AKA secure database.
+// Full path is not needed. The database eapaka.dat will be saved in the 
+// data cage path for DBMS. So it will be in "\private\100012a5\eapaka.dat" in C: drive.
+// The maximum length of database name is 0x40 (KDbMaxName) , which is defined in d32dbms.h.
+
+_LIT(KDatabaseName, "c:eapaka.dat");
 
-_LIT(KEapAkaDatabaseName, "eapaka.dat");
+_LIT(KSecureUIDFormat, "SECURE[102072e9]"); // For the security policy.
+
+#else
+
+_LIT(KDatabaseName, "c:\\system\\data\\eapaka.dat");
+
+#endif // #ifdef SYMBIAN_SECURE_DBMS
 
 _LIT(KAkaTableName, "eapaka");
 
 // CLASS DECLARATION
 class EapAkaDbUtils 
 {
-
 public:
 	
 	static void OpenDatabaseL(
 		RDbNamedDatabase& aDatabase, 
-		RFs& aFileServerSession,
+		RDbs& aSession, 
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
@@ -88,6 +98,7 @@
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
+
 };
 
 #endif // _EAPAKADBUTILS_H_